@@ -4,61 +4,62 @@
 #' @export
 #'
 #' @import "stats"
+#' @importFrom "dqrng" "dqrnorm" "dqset.seed"
 #'
-#' @param initial_price - initial price of the underlying asset.
-#' @param exercise_price - strike price of the option.
-#' @param r - risk-free interest rate.
-#' @param time_to_maturity - time to maturity.
-#' @param volatility - volatility of the underlying asset.
-#' @param dividend_yield - dividend yield.
+#' @param initial_price - initial price of the underlying asset
+#' @param exercise_price - strike price of the option
+#' @param r - risk-free interest rate
+#' @param time_to_maturity - time to maturity in years
+#' @param volatility - volatility of the underlying asset
+#' @param dividend_yield - dividend yield
 #' @param payoff - the payoff function, either a string in ("call", "put",
-#' "digital_call", "digital_put"), or a function.
-#' @param greek - the greek to be calculated.
-#' @param model - the model to be chosen.
-#' @param paths - the number of simulated paths.
+#' "digital_call", "digital_put"), or a function
+#' @param greek - the greek to be calculated
+#' @param model - the model to be chosen
+#' @param paths - the number of simulated paths
 #' @param seed - the seed of the random number generator
 #' @param antithetic - if TRUE, antithetic random numbers will be chosen to
 #' decrease variance
 #'
 #' @return Named vector containing the values of the Greeks specified in the
-#' parameter \code{greek}.
+#' parameter \code{greek}
 #'
 #' @examples Malliavin_European_Greeks(initial_price = 110, exercise_price = 100,
 #' r = 0.02, time_to_maturity = 4.5, dividend_yield = 0.015, volatility = 0.22,
 #' greek = c("fair_value", "delta", "rho"), payoff = "put")
 #'
 
-Malliavin_European_Greeks <- function(initial_price = 100,
-                                   exercise_price = 100,
-                                   r = 0,
-                                   time_to_maturity = 1,
-                                   volatility = 0.3,
-                                   dividend_yield = 0,
-                                   payoff = "call",
-                                   greek = c("fair_value", "delta", "vega",
-                                             "theta", "rho", "gamma"),
-                                   model = "Black Scholes",
-                                   paths = 10000,
-                                   seed = 1,
-                                   antithetic = FALSE) {
+Malliavin_European_Greeks <-
+  function(initial_price = 100,
+           exercise_price = 100,
+           r = 0,
+           time_to_maturity = 1,
+           volatility = 0.3,
+           dividend_yield = 0,
+           payoff = "call",
+           greek = c("fair_value", "delta", "vega", "theta", "rho", "gamma"),
+           model = "Black Scholes",
+           paths = 10000,
+           seed = 1,
+           antithetic = FALSE) {
 
   result <- vector(mode = "numeric", length = length(greek))
 
   names(result) <- greek
 
-  ## the seed is set locally
+  ## the seed is set
 
   if(!is.na(seed)) {
-    set.seed(seed)
+    dqset.seed(seed)
   }
 
   ## the increments of the Brownian motion ###
 
   if(antithetic == TRUE) {
-    W_T <- rnorm(n = paths/2, sd = sqrt(time_to_maturity))
+    W_T <- dqrnorm(n = paths/2, sd = sqrt(time_to_maturity))
     W_T <- rbind(W_T, -W_T)
   } else {
-    W_T <- rnorm(n = paths, sd = sqrt(time_to_maturity))
+    W_T <- dqrnorm(n = paths, sd = sqrt(time_to_maturity))
   }
 
   ### the payoff function ###
